@@ -6,3 +6,5 @@ admin.site.register(models.Source)
 admin.site.register(models.ContentType)
 admin.site.register(models.LocalContent)
 admin.site.register(models.WordSet)
+admin.site.register(models.UserAgent)
+admin.site.register(models.ProxyServer)
